pub struct ParsedEventMask {
pub kind: Option<EventKind>,
pub auxiliary_flags: EventAuxiliaryFlags,
}Expand description
A struct that provides structured access to event masks returned from reading an event from an inotify fd
Fields
kind: Option<EventKind>The kind of event that occurred
Inotify events that come from the kernel have exactly 0 or 1 of the flags associated with the event type set.
auxiliary_flags: EventAuxiliaryFlagsThe auxiliary flags about the event
Implementations
Sourceimpl ParsedEventMask
impl ParsedEventMask
Sourcepub fn from_parts(
kind: Option<EventKind>,
auxiliary_flags: EventAuxiliaryFlags,
) -> Self
pub fn from_parts( kind: Option<EventKind>, auxiliary_flags: EventAuxiliaryFlags, ) -> Self
Construct a ParsedEventMask from its component parts
Sourcepub fn from_raw_event_mask(mask: EventMask) -> Result<Self, EventMaskParseError>
pub fn from_raw_event_mask(mask: EventMask) -> Result<Self, EventMaskParseError>
Parse a raw event mask