pub struct EventAuxiliaryFlags {
pub ignored: bool,
pub isdir: bool,
pub unmount: bool,
}Expand description
Auxiliary flags for inotify events
The non-mutually-exclusive bitflags that may be set in an event read from an inotify fd. 0 or more of these bitflags may be set.
Fields
ignored: boolWatch was removed when explicitly removed via inotify_rm_watch(2)
or automatically (because the file was deleted or the filesystem was unmounted)
isdir: boolEvent subject is a directory rather than a regular file
unmount: boolFile system containing watched object was unmounted
An event with IN_IGNORED will subsequently be generated for the same watch descriptor.
Implementations
Sourceimpl EventAuxiliaryFlags
impl EventAuxiliaryFlags
Sourcepub fn from_raw_event_mask(mask: EventMask) -> Self
pub fn from_raw_event_mask(mask: EventMask) -> Self
Parse the auxiliary flags from a raw event mask